==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/breves/lang/breves_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/breves?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'breve' => 'Brève',
	'breves' => 'Brèva',

	// E
	'entree_breve_publiee' => 'Aquela brèva es :',
	'entree_texte_breve' => 'Tèst de la brèva',

	// I
	'icone_breves' => 'Brèva',
	'icone_ecrire_nouvel_article' => 'Li brèva countengudi en aquela rùbrica',
	'icone_modifier_breve' => 'Moudificà aquela brèva',
	'icone_nouvelle_breve' => 'Escriéure una nouvèla brèva',
	'info_1_breve' => '1 brèva',
	'info_aucun_breve' => 'Minga brèva',
	'info_breves' => 'Lou vouòstre sit utilisa lou sistema de brèva ?',
	'info_breves_02' => 'Brèva',
	'info_breves_valider' => 'Brèva de validà',
	'info_gauche_numero_breve' => 'Brèva nùmero',
	'info_nb_breves' => '@nb@ brèva',
	'item_breve_proposee' => 'Prepauada a la valutacioun',
	'item_breve_refusee' => 'refudada',
	'item_breve_validee' => 'validada',
	'item_non_utiliser_breves' => 'Noun utilisà li brèva',
	'item_utiliser_breves' => 'Utilisà li brèva',

	// L
	'logo_breve' => 'Logou da la brèva',

	// T
	'texte_breves' => 'Li brèva soun de tèstou court e simple que permeton de metre lèu en ligna d’infourmacioun counchisi, de gerà una revista de pressa, un calendari d’evenimen...',
	'titre_breve_proposee' => 'Breva prepauada',
	'titre_breve_publiee' => 'Breva publicada',
	'titre_breve_refusee' => 'Brèva refudada',
	'titre_breves' => 'Li brèva',
	'titre_langue_breve' => 'Lenga de la brèva',
	'titre_nouvelle_breve' => 'Nouvèla brèva',
	'titre_page_breves' => 'Brèva'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/breves/lang/breves_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/breves?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'breve' => 'Brèva',
	'breves' => 'Brèva',

	// E
	'entree_breve_publiee' => 'Aquela brèva es :',
	'entree_texte_breve' => 'Tèst de la brèva',

	// I
	'icone_breves' => 'Brèva',
	'icone_ecrire_nouvel_article' => 'Li brèva countengudi en aquesta rùbrica',
	'icone_modifier_breve' => 'Moudificà aquela brèva',
	'icone_nouvelle_breve' => 'Escriéure una nouvèla brèva',
	'info_1_breve' => '1 brèva',
	'info_aucun_breve' => 'Minga brèva',
	'info_breves' => 'Lou vouòstre sit utilisa lou sistema de brèva ?',
	'info_breves_02' => 'Brèva',
	'info_breves_valider' => 'Brèva da validà',
	'info_gauche_numero_breve' => 'Brèva nùmero',
	'info_nb_breves' => '@nb@ brèva',
	'item_breve_proposee' => 'Prepauada à la valutacioun',
	'item_breve_refusee' => 'refudada',
	'item_breve_validee' => 'validada',
	'item_non_utiliser_breves' => 'Noun utilisà li brèva',
	'item_utiliser_breves' => 'Utilisà li brèva',

	// L
	'logo_breve' => 'Logou de la brèva',

	// T
	'texte_breves' => 'Li brèva soun de tèstou court e simple que permeton de metre lèu en ligna d’infourmacioun counchisi, de gerà una revista de pressa, un calendari d’evenimen...',
	'titre_breve_proposee' => 'Breva prepauada',
	'titre_breve_publiee' => 'Breva publicada',
	'titre_breve_refusee' => 'Brèva refudada',
	'titre_breves' => 'Li brèva',
	'titre_langue_breve' => 'Lenga de la brèva',
	'titre_nouvelle_breve' => 'Nouvèla brèva',
	'titre_page_breves' => 'Brèva'
);

?>
